//Exemplo que permite mover o ponteiro e usar o botão esquerdo do mouse

//https://www.youtube.com/BitaBit

//https://www.bitabittecnologia.com.br

//Link para o vídeo que utiliza este código: https://www.youtube.com/watch?v=1hw_mmkdxLc&t=617s


#include <SerialMouseKeyboardControl.h>

SerialMouseKeyboardControl smkc;

//Definição dos pinos do joystick e botão
const int eixoY = A0;         
const int eixoX = A1;
const int botaoEsquerdoMouse = 2;

//Configuração controle do joystick
const int sensibilidadeJoystick = 20;
const int delayRespostaMouse = 10;
const int zonaMorta = 2; //Faz o mouse não mover sozinho quando o joystick estiver em descanso

unsigned long int controleRespostaMouse = 0;

//Obter o valor dos eixos do joystick
int obterEixoJoystick(int eixo)
{
  int valorEixo = analogRead(eixo);
  int valorMinimo = sensibilidadeJoystick - sensibilidadeJoystick*2;
  int valorMaximo = sensibilidadeJoystick;
  
  valorEixo = map(valorEixo, 0, 1023, valorMinimo, valorMaximo);

  if (abs(valorEixo) < zonaMorta) 
  {
    valorEixo = 0;
  }

  return valorEixo;
}

//Setar botões direito e esquerdo do mouse
void setBotaoMouse(int pinoBotao)
{
  if(pinoBotao == botaoEsquerdoMouse)
  {
    if(!digitalRead(botaoEsquerdoMouse))
    {
      if(!smkc.mouseLeftIsPressed()) 
      {
        smkc.mouseLeftPress();
      }
    }
    else
    {
      if(smkc.mouseLeftIsPressed()) 
      {
        smkc.mouseLeftRelease();
      }
    }
  }
}

void setup() 
{
  //SerialMouseKeyboardControl usa Serial. Defina o Baud Rate desejado.
  //O exemplo utiliza Baud Rate 9600.
  Serial.begin(9600);
  
  pinMode(botaoEsquerdoMouse, INPUT_PULLUP);
}

void loop() 
{
  int valorEixoX = 0;
  int valorEixoY = 0;
  
    if(( millis() - controleRespostaMouse) > delayRespostaMouse)
    {
      //Obtém os valores do joystick e controla o mouse
      valorEixoX = obterEixoJoystick(eixoX);
      valorEixoY = obterEixoJoystick(eixoY);
      smkc.mouseMove(valorEixoX, valorEixoY); //Move o ponteiro do mouse a partir da posição atual
      
      controleRespostaMouse = millis();
    }
    
    //Botão do mouse
    setBotaoMouse(botaoEsquerdoMouse);
  
  delay(delayRespostaMouse);
}